import { YandexAuth } from "@zebrainy/contracts";
import { AvailableSubscriptionProducts, ChildAge, DownloadStatus, GameDownloadStatus, GameMapConfigTransformed, Initialize, RemoteConfigType, GameMapConfigSource, IntercomUserInfo } from "@zebrainy/front-types";
import { Result } from "runtypes";
import { CatalogConfig, CatalogFilterCondition, CatalogSection, CatalogTile, CatalogTileFilter, CatalogTileOrSectionWrapper, CatalogTileWrapper, TileTarget } from "@zebrainy/catalog-config";
import express from "express";
export declare const wait: (ms: number) => Promise<unknown>;
export declare const flatten: (obj: Record<string, any>) => Record<string, any>;
export declare const stringifyErr: (e: unknown) => string;
export declare const exressHandleError: express.ErrorRequestHandler;
export declare function callWithArgsInForEach<TArgs extends any[]>(...args: TArgs): (cb: (...args: TArgs) => void) => void;
/**
 * Функция переводит миллисекунды к секундам, оставляя дробную часть
 * @param  {number} ms
 * @example
 * approxSeconds(1530) вернёт 1.5
 * @example
 * approxSeconds(1580) вернёт 1.6
 */
export declare function approxSeconds(ms: number): number;
/**
 * Функция переводит милисекунды в секунды и округляет результат
 * @param  {number} ms
 */
export declare function roundSeconds(ms: number): number;
/**
 * @param  {string} a
 * @param  {string} b
 * @param  {'=='|'<'|'<='|'>'|'>='} op
 * @example
 * compareVersions("8.0.1", "7.0.1", ">") вернёт true, потому что 8.0.1 больше 7.0.1
 */
export declare function compareVersions(a: string, b: string, op: "==" | "<" | "<=" | ">" | ">="): boolean;
/**
 * Фунцкия округляет число
 * @param  {number} price
 */
export declare const getRoundedPrice: (price: number) => number;
export declare const getPriceWithDecimalPlaces: (price: number) => number;
/**
 * Функция считает указанный персентиль. См. https://en.wikipedia.org/wiki/Percentile
 * @param  {T[]} arr
 * @param  {number} percent
 * @example
 * percentile([15, 20, 35, 40, 50], 0.40) вернёт 40-ой персентиль
 */
export declare const percentile: <T>(arr: T[], percent: number) => T | undefined;
export declare const calculateParentCount: (hours: number) => number;
/**
 * Генерирует число на отрезке [min, max]
 * @param  {number} min
 * @param  {number} max
 */
export declare const random: (min: number, max: number) => number;
export declare const parseWeeks: <T extends Pick<{
    MarketID: string;
    Price: number;
    Type: number;
} & {
    TargetMarketPlatform?: number | null | undefined;
    LocalizedPrice?: string | null | undefined;
    Currency?: string | null | undefined;
    MarketProduct?: {
        definition?: {
            id?: string | null | undefined;
            storeSpecificId?: string | null | undefined;
            type?: number | null | undefined;
            enabled?: boolean | null | undefined;
            payouts?: string[] | null | undefined;
        } | undefined;
        metadata?: {
            localizedPriceString?: string | undefined;
            localizedTitle?: string | undefined;
            localizedDescription?: string | null | undefined;
            isoCurrencyCode?: string | undefined;
            localizedPrice?: number | undefined;
        } | undefined;
        availableToPurchase?: boolean | null | undefined;
        transactionID?: string | null | undefined;
        receipt?: string | null | undefined;
    } | null | undefined;
    SubscriptionTimeType?: number | undefined;
    Duration?: string | null | undefined;
    ServerMonths?: number | null | undefined;
    IntroductoryLocalizedPrice?: string | null | undefined;
    TrialString?: string | null | undefined;
    DiscountString?: string | null | undefined;
    IntroductoryPrice?: string | null | undefined;
    IsTrialOrIntroPeriodPassed?: boolean | null | undefined;
    SubscriptionGroupId?: number | null | undefined;
    IntroductoryPricePeriod?: string | null | undefined;
    FreeTrialPeriod?: string | null | undefined;
    IsProductIntroOrTrial?: boolean | null | undefined;
    FreeTrialPeriodNative?: string | null | undefined;
    IntroductoryPricePeriodNative?: string | null | undefined;
    Description?: {
        en: string;
        ru: string;
    } | null | undefined;
}, "Duration">>(sub: T) => number;
export declare const parseMonth: <T extends Pick<{
    MarketID: string;
    Price: number;
    Type: number;
} & {
    TargetMarketPlatform?: number | null | undefined;
    LocalizedPrice?: string | null | undefined;
    Currency?: string | null | undefined;
    MarketProduct?: {
        definition?: {
            id?: string | null | undefined;
            storeSpecificId?: string | null | undefined;
            type?: number | null | undefined;
            enabled?: boolean | null | undefined;
            payouts?: string[] | null | undefined;
        } | undefined;
        metadata?: {
            localizedPriceString?: string | undefined;
            localizedTitle?: string | undefined;
            localizedDescription?: string | null | undefined;
            isoCurrencyCode?: string | undefined;
            localizedPrice?: number | undefined;
        } | undefined;
        availableToPurchase?: boolean | null | undefined;
        transactionID?: string | null | undefined;
        receipt?: string | null | undefined;
    } | null | undefined;
    SubscriptionTimeType?: number | undefined;
    Duration?: string | null | undefined;
    ServerMonths?: number | null | undefined;
    IntroductoryLocalizedPrice?: string | null | undefined;
    TrialString?: string | null | undefined;
    DiscountString?: string | null | undefined;
    IntroductoryPrice?: string | null | undefined;
    IsTrialOrIntroPeriodPassed?: boolean | null | undefined;
    SubscriptionGroupId?: number | null | undefined;
    IntroductoryPricePeriod?: string | null | undefined;
    FreeTrialPeriod?: string | null | undefined;
    IsProductIntroOrTrial?: boolean | null | undefined;
    FreeTrialPeriodNative?: string | null | undefined;
    IntroductoryPricePeriodNative?: string | null | undefined;
    Description?: {
        en: string;
        ru: string;
    } | null | undefined;
}, "Duration">>(sub: T) => number;
/**
 * Генерирует число на отрезке [min, max], исключая числа из указанного множества excludedNumbers
 * @param  {number} min
 * @param  {number} max
 * @param  {number[]} excludedNumbers

 */
export declare const randomExclude: (min: number, max: number, excludedNumbers: number[]) => number;
/**
 * Функция возвращает указанное число n в виде строки, используя словарь numbers
 * Работает с числами на отрезке [0,99]
 * @param  {number} n
 * @param  {Record<number, string| undefined} numbers
 */
export declare function getNumberString(n: number, numbers: Record<number, string | undefined>): string | undefined;
/**
 * Функция проверяет, является ли переданная подписка триальной
 * @param  {AvailableSubscriptionProducts} sub
 */
export declare const isTrial: (sub: AvailableSubscriptionProducts) => boolean;
/**
 * Функция скроллит экран по горизонтали к заданному HTML елементу за указанное время в сек.
 * @param  {HTMLDivElement} container
 * @param  {HTMLDivElement} elm
 * @param  {number} duration
 */
export declare function scrollToElm(container: HTMLDivElement, elm: HTMLDivElement, duration: number): void;
/**
 * Функция рассчитывает положение HTML элемента на странице относительно каждой из сторон
 * @param  {HTMLDivElement} elm
 */
export declare function getRelativePos(elm: HTMLDivElement): Record<string, number>;
/**
 * Easing-функция для более плавной анимации
 * @param  {number} t
 */
export declare const easeInOutCubic: (t: number) => number;
/**
 * Функция для горизонтального скроллинга элемента
 * @param  {HTMLDivElement} element
 * @param  {number} to
 * @param  {number} duration
 * @param  {() => void} onDone
 */
export declare function scrollTo(element: HTMLDivElement, to: number, duration: number, onDone?: () => void): void;
export declare function appendLink(rel: "preload" | "preconnect" | "dns-prefetch", href: string, props?: Record<string, string | boolean>): void;
/**
 * От клиента может прийти одна подписка,
 * тогда мы их дублируем и рисумем только одну,
 * а эта функция позволяет понять, была ли дублирована подписка
 * @param  {AvailableSubscriptionProducts[]} products
 */
export declare const __UNFUCK_SUBSCRIPTIONS_HIDDEN: (products: AvailableSubscriptionProducts[]) => boolean;
/**
 * Функция нужна для валидации рантайпсом флагов ремоут конфига. Она валидирует,
 * проставляет дефолтное значение, если исходное невалидно, и возвращает его.
 * Также предоставляет возможность указать колбек,
 * который вызовется при ошибке валидации с итоговым значением флага и дополнительной информацией об ошибке валидации
 * @param toValidate
 * @param defaultValue
 * @param invalidCallback
 * @param validator
 */
export declare const ValidateAndGetDefaultValue: <T>(toValidate: Required<T>, defaultValue: Required<T>, invalidCallback: (value: Required<T>, msg: string) => void, validator: (x: any) => Result<T>) => Required<T>;
/**
 * Функция мапает массив в объект. Ключи объекта -- результаты приминения функции getKey к элементам массива
 * @param array
 * @param getKey
 */
export declare function arrayToRecord<T, K extends string>(array: T[], getKey: (val: T) => K): Record<K, T>;
/**
 * Функция возвращает объект, состоящий из полей,
 * которые являются результатами приминения функции transform к полям объекта record
 * @param record
 * @param transform
 */
export declare function mapRecord<K extends string, V, U>(record: Record<K, V>, transform: (val: V) => U): Record<K, U>;
/**
 * Функция преобразует строку для установки в свойство тега {id}
 * Заменяет двоеточия(:) на дефис(-)
 * @param {string} gameId
 */
export declare const sanitizeGameIdForHtmlId: (gameId: string) => string;
/**
 * Функция циклически сдвигает массив, сдвигая элемент oldIndex на newIndex...
 * @param  arr
 * @param  oldIndex
 * @param  newIndex
 */
export declare function moveElementOnArray<T extends any>(arr: T[], oldIndex: number, newIndex: number): T[];
/**
 * Функция удаляет элементы массива, которые являются одинаковыми с точки зрения переданной функции eq
 * @param  arr
 * @param  eq
 * @example
 * deleteDuplicates([1,1,1,0,22,3,444,5], (a,b) => a == b) вернёт [1,0,2,3,4,5]
 */
export declare const deleteDuplicates: <T extends unknown>(arr: T[], eq: (a: T, b: T) => boolean) => T[];
/**
 * Получает строку если строка превышает заданный лимит заменяет последние символы на троеточие(...)
 * И дополнительно обрезает её от лишних пробелов
 * @param {string} text
 * @param {number} limit
 */
export declare function cutString(text: string, limit: number): string;
/**
 * Действует аналогично свойству CSS text-transform: capitalize
 * @param  {string} text
 */
export declare const capitalizeText: (text: string) => string;
/**
 * Генерирует массив чисел, от и до указанного значения, приведенных к строке
 * @param {string} text
 * @param {number} limit
 */
export declare function generateNumberArray(begin: number, end: number): string[];
/**
 * На
 * @param {string} text
 * @param {number} limit
 */
export declare const calcAgeCategory: (month: number, year: number) => 10 | 16 | 13 | 14 | 15 | 17;
export declare const mapAgeToCategory: (arg: number) => 10 | 16 | 13 | 14 | 15 | 17;
export declare const mapAgeToNumberEdge: (age: ChildAge) => number;
export declare const mapCategoryToAgeString: (arg: number) => ChildAge;
/**
 * Валидирует подписку рантайпсом
 * и предоставляет возможность передать хуки на случаи: \
 * если подписок в массиве products 0,1,2, мало(0 или 1) и много(больше 2); \
 * если произошла ошибка валидации
 */
export declare const setSubscriptionsProducts: (args: {
    products: AvailableSubscriptionProducts[];
    handleZeroCount: () => void;
    handleOneCount: () => void;
    handleTwoCount: () => void;
    validationErrorCallback: () => void;
    handleFewCount: (count: number) => void;
    handleManyCount: (count: number) => void;
}) => void;
/**
 * Принимает массив FPS и составляет объект со статистикой по фпс на данный момент
 */
export declare const calculateFpsStats: (samples: number[]) => {
    FPS_AVERAGE: number;
    FPS_SLOWEST_10: number;
    FPS_MEDIAN_50: number;
    FPS_LEVEL: string;
    FPS_RECENT_AVG: number;
};
/**
 * Высчитывает значение FPS
 */
export declare const calcFps: (frameTime: number) => number;
/**
 * @param {number} parentId
 * @param {string} udid
 * Выдёт строку с префиксом p_{@param parentId}  или d_{@param udid} в зависимости от пришедшого parentId
 */
export declare const getIntercomUserId: (parentId: Initialize["parentId"], udid: Initialize["udid"]) => string;
export declare const loadScript: (src: string) => Promise<unknown>;
/**
 * @param {object} oldObj
 * @param {object} newObj
 * @param onTypeMismatch
 * @param levelKey генератор путей. При первом запуске это будет просто префикс для всех ключей в функции onTypeMismatch.key
 * Функция накатывает объект newObj поверх oldObj. !!! Если в объекте oldObj нет поля, которое есть в newObj, то в oldObj закидывается ссылка на это поле из newObj
 * onTypeMismatch вызывается при несоответствии типов сравниваемых полей.
 * в параметры передается информация о том, в каком поле произошла ошибка и сами сравниваемые значения, чтобы четко видеть, в чем проблема
 *
 */
export declare const mergeObjects: (oldObj: Record<string, any>, newObj: Record<string, any>, onTypeMismatch: (info: {
    key: string;
    oldValue: string;
    newValue: string;
}) => void, levelKey?: string) => Record<string, any>;
/**
 * @param {any} array
 * Перемешивает заданный {@param array} в рандомном порядке
 */
export declare function shuffleArray<T extends any>(array: T[]): T[];
/**
 * @param {Promise<T>} p
 * Оборачивает axios-запрос {@param p} и отправляет в консоль сообщение об ошибке при попадании в блок catch
 */
export declare const unwrapAxiosError: <T>(p: Promise<T>) => Promise<T>;
export declare const exponentialBackoff: <T>(p: () => Promise<T>, maxRetries: number) => Promise<T>;
/**
 * Функция возвращает новый @param record с отфильтрованными полями на основании условия указанного в @param transform
 * @param record
 * @param transform
 */
export declare const objectfilter: <K extends string, V>(record: Record<K, V>, transform: (val: V) => boolean) => Record<K, V>;
/**
 * Функция возвращает новый @param array c количеством элементов указнном в @param n
 * @param record
 * @param n
 */
export declare const take: <T extends any[]>(array: T, n?: number) => T;
/**
 * Функция нормализует строку по правилу Мурада
 * @param s
 */
export declare const normalizePriceString: (s: string) => string;
export declare const runningOnLocalMobileWebserver: (isDesktop: boolean) => boolean;
export declare const urlIsUsingCache: (url: string) => boolean;
export declare const getPathFromCacheUrl: (url: string) => string;
export declare const cacheUrlToHttp: (protocols: Record<string, string>, url: string) => string;
export declare const checkDownloadStatus: (downloadStatus: DownloadStatus | null | undefined) => GameDownloadStatus;
export declare function omit<T, U extends keyof T>(obj: T, ...fields: U[]): Omit<T, U>;
/**
 * @deprecated use format instead
 */
export declare function formatString(src: string, substitutions: Record<string, any>): string;
/**
 * возвращает форму множественного числа 0,1,2
 */
export declare const pluralizer: (num: number) => 2 | 0 | 1;
/**
 * Функция заменяет в строке вхождения '{k}' на ключ k в params
 * - Первым аргументом передаётся строка -- шаблон
 * - Следующие аргументы -- строки подстановки
 * - Также можно использовать функцию для вычисления множественных форм, для этого надо указать в шаблоне до трех значений, перечисленных через |
 * @example format("{0}{1}{0}", "w", "o") -> "wow"
 * @example format("{0:Первая|Первые} {0} {0:неделя|недели|недель}", 3) -> "Первые 3 недели"
 * @example format("{0:Первая|Первые} {0} {0:неделя|недели|недель}", 31) -> "Первая 31 неделя"
 */
export declare const format: (template: string, ...params: string[]) => string;
export declare const getPaywallTimer: (t: number) => number[];
export type EnumKeys<Enum> = Exclude<keyof Enum, number>;
export declare const enumObject: <Enum extends Record<string, string | number>>(e: Enum) => { [K in Exclude<keyof Enum, number>]: Enum[K]; };
export declare const enumObjectReversed: <Enum extends Record<string, string | number>>(e: Enum) => any;
export declare const enumKeys: <Enum extends Record<string, string | number>>(e: Enum) => Exclude<keyof Enum, number>[];
export declare const addZerosToSingleDigit: (str: string) => string;
export declare const EMAIL_REGEX: RegExp;
export declare const validateEmail: (email: string) => boolean;
export declare function _compareStrings(a: string | number, b: string | number): "==" | "<" | ">";
export declare function compareStrings(a: string | number, b: string | number, op: "==" | "<" | "<=" | ">" | ">=" | "!=" | "in"): boolean;
export declare const gameVisible: (tile: Pick<CatalogTileOrSectionWrapper, "tile"> & {
    filter?: CatalogTileFilter[];
}, statuses: RemoteConfigType["webgames-status"], state: Initialize) => boolean;
export declare const filterCondition: (fltr: CatalogTileFilter[], state: Initialize) => boolean;
export declare const checkCondition: (condition: CatalogFilterCondition, state: Initialize) => boolean;
export declare function isGame(tile: CatalogTile | CatalogSection): tile is CatalogTile;
export declare const isSection: (tile: CatalogTile | CatalogSection) => tile is CatalogSection;
export declare function getGameId(tile?: CatalogTile | CatalogSection): string;
export declare const getGameIdFromTarget: (tt?: TileTarget) => string;
export declare function getGameParams(tt?: TileTarget): {
    name: string;
    value: {};
}[];
export declare const extractGameType: (tt?: TileTarget) => any;
export declare const exhaustive_switch: (c: never) => never;
export declare const restrictedInOffline: (onlineStatus: boolean, downloadStatus: DownloadStatus, restrictInOffline: boolean, gameLocked: boolean) => boolean;
export declare const shouldShowTinkoffPaywall: (data: Initialize) => boolean | undefined;
export declare const shouldShowCloudPaymentsPaywall: (data: Initialize) => boolean | undefined;
export declare const downloadValidCatalogConfig: (url: string, onValidationFail: (details: string) => void) => Promise<{
    v: string;
    settings: {
        v?: string | null | undefined;
    };
    tiles: ({
        repeat: number | null | undefined;
        filter: {
            id?: string | undefined;
            conditions?: {
                type?: "language" | "subscriptionKind" | "ios_version" | "android_version" | "memory_size" | "permissions" | "platform" | "client_version" | undefined;
                mod?: "==" | "<" | "<=" | ">" | ">=" | "!=" | "in" | undefined;
                value?: string | undefined;
            }[] | undefined;
        }[];
        tile: CatalogSection | {
            title: {
                ru?: string | null | undefined;
                en?: string | null | undefined;
            } | null | undefined;
            filter: {
                id?: string | undefined;
                conditions?: {
                    type?: "language" | "subscriptionKind" | "ios_version" | "android_version" | "memory_size" | "permissions" | "platform" | "client_version" | undefined;
                    mod?: "==" | "<" | "<=" | ">" | ">=" | "!=" | "in" | undefined;
                    value?: string | undefined;
                }[] | undefined;
            }[];
            "tech-name": string | null | undefined;
            subtitle: {
                ru?: string | null | undefined;
                en?: string | null | undefined;
            } | null | undefined;
            topTitle: {
                ru?: string | null | undefined;
                en?: string | null | undefined;
            } | null | undefined;
            target: {
                configUrl: string | null | undefined;
                type: "bg";
                gameId: string;
                restrictInOffline: boolean | null | undefined;
                params: {
                    name: string;
                    value: {};
                }[];
            } | {
                type: "mg";
                gameId: string;
                restrictInOffline: boolean | null | undefined;
            } | ({
                type: "partner";
                name: string;
            } & {
                restrictInOffline?: boolean | null | undefined;
            }) | {
                type: "island";
                restrictInOffline: boolean | null | undefined;
            } | {
                configUrl: string | null | undefined;
                type: "wg";
                gameId: string;
                restrictInOffline: boolean | null | undefined;
            } | ({
                type: "locked";
                gameId: string;
            } & {
                restrictInOffline?: boolean | null | undefined;
                params?: {
                    name: string;
                    value: {};
                }[] | null | undefined;
            });
            img700x500: string | null | undefined;
            previewAnimation: string | null | undefined;
            tags: {
                name: {
                    ru?: string | null | undefined;
                    en?: string | null | undefined;
                };
                color: string;
            }[] | null | undefined;
            freeContentAmount: number | null | undefined;
            blockedByPaywall: boolean | null | undefined;
            availableFrom: string | null | undefined;
            update: {
                id: string;
                startDate: string;
                endDate: string;
                schemaId: string;
            }[] | null | undefined;
            animatedTile: string | null | undefined;
            bookmark: boolean | null | undefined;
            hideWhiteShadow: boolean | null | undefined;
            unlockTimerSeconds: number | null | undefined;
        };
        disabled: boolean | null | undefined;
        return: boolean | null | undefined;
        highlighted: boolean | null | undefined;
        tilesize: "small" | "large" | null | undefined;
        "override-freeContentAmount": boolean | null | undefined;
        "new-freeContentAmount": number | null | undefined;
    } & {
        "animation-id"?: string | null | undefined;
        blockedByPaywall?: boolean | null | undefined;
    })[];
    "game-day": {
        Description: {
            ru?: string | null | undefined;
            en?: string | null | undefined;
        };
        img: string;
        name: string;
        "switch-period": string;
        "tile-array": {
            tile: {
                title: {
                    ru?: string | null | undefined;
                    en?: string | null | undefined;
                } | null | undefined;
                filter: {
                    id?: string | undefined;
                    conditions?: {
                        type?: "language" | "subscriptionKind" | "ios_version" | "android_version" | "memory_size" | "permissions" | "platform" | "client_version" | undefined;
                        mod?: "==" | "<" | "<=" | ">" | ">=" | "!=" | "in" | undefined;
                        value?: string | undefined;
                    }[] | undefined;
                }[];
                "tech-name": string | null | undefined;
                subtitle: {
                    ru?: string | null | undefined;
                    en?: string | null | undefined;
                } | null | undefined;
                topTitle: {
                    ru?: string | null | undefined;
                    en?: string | null | undefined;
                } | null | undefined;
                target: {
                    configUrl: string | null | undefined;
                    type: "bg";
                    gameId: string;
                    restrictInOffline: boolean | null | undefined;
                    params: {
                        name: string;
                        value: {};
                    }[];
                } | {
                    type: "mg";
                    gameId: string;
                    restrictInOffline: boolean | null | undefined;
                } | ({
                    type: "partner";
                    name: string;
                } & {
                    restrictInOffline?: boolean | null | undefined;
                }) | {
                    type: "island";
                    restrictInOffline: boolean | null | undefined;
                } | {
                    configUrl: string | null | undefined;
                    type: "wg";
                    gameId: string;
                    restrictInOffline: boolean | null | undefined;
                } | ({
                    type: "locked";
                    gameId: string;
                } & {
                    restrictInOffline?: boolean | null | undefined;
                    params?: {
                        name: string;
                        value: {};
                    }[] | null | undefined;
                });
                img700x500: string | null | undefined;
                previewAnimation: string | null | undefined;
                tags: {
                    name: {
                        ru?: string | null | undefined;
                        en?: string | null | undefined;
                    };
                    color: string;
                }[] | null | undefined;
                freeContentAmount: number | null | undefined;
                blockedByPaywall: boolean | null | undefined;
                availableFrom: string | null | undefined;
                update: {
                    id: string;
                    startDate: string;
                    endDate: string;
                    schemaId: string;
                }[] | null | undefined;
                animatedTile: string | null | undefined;
                bookmark: boolean | null | undefined;
                hideWhiteShadow: boolean | null | undefined;
                unlockTimerSeconds: number | null | undefined;
            };
            "override-freeContentAmount": boolean | null | undefined;
            "new-freeContentAmount": number | null | undefined;
            blockedByPaywall: boolean | null | undefined;
        }[];
    };
    "chosen-one-games": {
        filter: {
            id?: string | undefined;
            conditions?: {
                type?: "language" | "subscriptionKind" | "ios_version" | "android_version" | "memory_size" | "permissions" | "platform" | "client_version" | undefined;
                mod?: "==" | "<" | "<=" | ">" | ">=" | "!=" | "in" | undefined;
                value?: string | undefined;
            }[] | undefined;
        }[];
        tile: {
            title: {
                ru?: string | null | undefined;
                en?: string | null | undefined;
            } | null | undefined;
            filter: {
                id?: string | undefined;
                conditions?: {
                    type?: "language" | "subscriptionKind" | "ios_version" | "android_version" | "memory_size" | "permissions" | "platform" | "client_version" | undefined;
                    mod?: "==" | "<" | "<=" | ">" | ">=" | "!=" | "in" | undefined;
                    value?: string | undefined;
                }[] | undefined;
            }[];
            "tech-name": string | null | undefined;
            subtitle: {
                ru?: string | null | undefined;
                en?: string | null | undefined;
            } | null | undefined;
            topTitle: {
                ru?: string | null | undefined;
                en?: string | null | undefined;
            } | null | undefined;
            target: {
                configUrl: string | null | undefined;
                type: "bg";
                gameId: string;
                restrictInOffline: boolean | null | undefined;
                params: {
                    name: string;
                    value: {};
                }[];
            } | {
                type: "mg";
                gameId: string;
                restrictInOffline: boolean | null | undefined;
            } | ({
                type: "partner";
                name: string;
            } & {
                restrictInOffline?: boolean | null | undefined;
            }) | {
                type: "island";
                restrictInOffline: boolean | null | undefined;
            } | {
                configUrl: string | null | undefined;
                type: "wg";
                gameId: string;
                restrictInOffline: boolean | null | undefined;
            } | ({
                type: "locked";
                gameId: string;
            } & {
                restrictInOffline?: boolean | null | undefined;
                params?: {
                    name: string;
                    value: {};
                }[] | null | undefined;
            });
            img700x500: string | null | undefined;
            previewAnimation: string | null | undefined;
            tags: {
                name: {
                    ru?: string | null | undefined;
                    en?: string | null | undefined;
                };
                color: string;
            }[] | null | undefined;
            freeContentAmount: number | null | undefined;
            blockedByPaywall: boolean | null | undefined;
            availableFrom: string | null | undefined;
            update: {
                id: string;
                startDate: string;
                endDate: string;
                schemaId: string;
            }[] | null | undefined;
            animatedTile: string | null | undefined;
            bookmark: boolean | null | undefined;
            hideWhiteShadow: boolean | null | undefined;
            unlockTimerSeconds: number | null | undefined;
        };
        "override-freeContentAmount": boolean | null | undefined;
        "new-freeContentAmount": number | null | undefined;
        blockedByPaywall: boolean | null | undefined;
        event: {
            img: string;
            name: {
                ru?: string | null | undefined;
                en?: string | null | undefined;
            };
        };
        "start-date": string;
        "end-date": string;
    }[];
    "start-screen": {
        video: string;
        poster: string;
    };
} | undefined>;
export declare const getCatalogConfigUrl: (childAge: ChildAge, remoteConfig?: RemoteConfigType | null) => string;
export declare const tryDownloadCatalogConfig: (url: string, fallbackUrl: string, handlers: {
    onTryStart: (url: string, attempt: number) => void;
    onTryFinished: (isValid: boolean, url: string) => void;
    onFallbackReceived: (isValid: boolean, url: string) => void;
    onFileRemoveRequest: (url: string) => void;
    onValidationFailed: (details: string) => void;
}) => Promise<{
    v: string;
    settings: {
        v?: string | null | undefined;
    };
    tiles: ({
        repeat: number | null | undefined;
        filter: {
            id?: string | undefined;
            conditions?: {
                type?: "language" | "subscriptionKind" | "ios_version" | "android_version" | "memory_size" | "permissions" | "platform" | "client_version" | undefined;
                mod?: "==" | "<" | "<=" | ">" | ">=" | "!=" | "in" | undefined;
                value?: string | undefined;
            }[] | undefined;
        }[];
        tile: CatalogSection | {
            title: {
                ru?: string | null | undefined;
                en?: string | null | undefined;
            } | null | undefined;
            filter: {
                id?: string | undefined;
                conditions?: {
                    type?: "language" | "subscriptionKind" | "ios_version" | "android_version" | "memory_size" | "permissions" | "platform" | "client_version" | undefined;
                    mod?: "==" | "<" | "<=" | ">" | ">=" | "!=" | "in" | undefined;
                    value?: string | undefined;
                }[] | undefined;
            }[];
            "tech-name": string | null | undefined;
            subtitle: {
                ru?: string | null | undefined;
                en?: string | null | undefined;
            } | null | undefined;
            topTitle: {
                ru?: string | null | undefined;
                en?: string | null | undefined;
            } | null | undefined;
            target: {
                configUrl: string | null | undefined;
                type: "bg";
                gameId: string;
                restrictInOffline: boolean | null | undefined;
                params: {
                    name: string;
                    value: {};
                }[];
            } | {
                type: "mg";
                gameId: string;
                restrictInOffline: boolean | null | undefined;
            } | ({
                type: "partner";
                name: string;
            } & {
                restrictInOffline?: boolean | null | undefined;
            }) | {
                type: "island";
                restrictInOffline: boolean | null | undefined;
            } | {
                configUrl: string | null | undefined;
                type: "wg";
                gameId: string;
                restrictInOffline: boolean | null | undefined;
            } | ({
                type: "locked";
                gameId: string;
            } & {
                restrictInOffline?: boolean | null | undefined;
                params?: {
                    name: string;
                    value: {};
                }[] | null | undefined;
            });
            img700x500: string | null | undefined;
            previewAnimation: string | null | undefined;
            tags: {
                name: {
                    ru?: string | null | undefined;
                    en?: string | null | undefined;
                };
                color: string;
            }[] | null | undefined;
            freeContentAmount: number | null | undefined;
            blockedByPaywall: boolean | null | undefined;
            availableFrom: string | null | undefined;
            update: {
                id: string;
                startDate: string;
                endDate: string;
                schemaId: string;
            }[] | null | undefined;
            animatedTile: string | null | undefined;
            bookmark: boolean | null | undefined;
            hideWhiteShadow: boolean | null | undefined;
            unlockTimerSeconds: number | null | undefined;
        };
        disabled: boolean | null | undefined;
        return: boolean | null | undefined;
        highlighted: boolean | null | undefined;
        tilesize: "small" | "large" | null | undefined;
        "override-freeContentAmount": boolean | null | undefined;
        "new-freeContentAmount": number | null | undefined;
    } & {
        "animation-id"?: string | null | undefined;
        blockedByPaywall?: boolean | null | undefined;
    })[];
    "game-day": {
        Description: {
            ru?: string | null | undefined;
            en?: string | null | undefined;
        };
        img: string;
        name: string;
        "switch-period": string;
        "tile-array": {
            tile: {
                title: {
                    ru?: string | null | undefined;
                    en?: string | null | undefined;
                } | null | undefined;
                filter: {
                    id?: string | undefined;
                    conditions?: {
                        type?: "language" | "subscriptionKind" | "ios_version" | "android_version" | "memory_size" | "permissions" | "platform" | "client_version" | undefined;
                        mod?: "==" | "<" | "<=" | ">" | ">=" | "!=" | "in" | undefined;
                        value?: string | undefined;
                    }[] | undefined;
                }[];
                "tech-name": string | null | undefined;
                subtitle: {
                    ru?: string | null | undefined;
                    en?: string | null | undefined;
                } | null | undefined;
                topTitle: {
                    ru?: string | null | undefined;
                    en?: string | null | undefined;
                } | null | undefined;
                target: {
                    configUrl: string | null | undefined;
                    type: "bg";
                    gameId: string;
                    restrictInOffline: boolean | null | undefined;
                    params: {
                        name: string;
                        value: {};
                    }[];
                } | {
                    type: "mg";
                    gameId: string;
                    restrictInOffline: boolean | null | undefined;
                } | ({
                    type: "partner";
                    name: string;
                } & {
                    restrictInOffline?: boolean | null | undefined;
                }) | {
                    type: "island";
                    restrictInOffline: boolean | null | undefined;
                } | {
                    configUrl: string | null | undefined;
                    type: "wg";
                    gameId: string;
                    restrictInOffline: boolean | null | undefined;
                } | ({
                    type: "locked";
                    gameId: string;
                } & {
                    restrictInOffline?: boolean | null | undefined;
                    params?: {
                        name: string;
                        value: {};
                    }[] | null | undefined;
                });
                img700x500: string | null | undefined;
                previewAnimation: string | null | undefined;
                tags: {
                    name: {
                        ru?: string | null | undefined;
                        en?: string | null | undefined;
                    };
                    color: string;
                }[] | null | undefined;
                freeContentAmount: number | null | undefined;
                blockedByPaywall: boolean | null | undefined;
                availableFrom: string | null | undefined;
                update: {
                    id: string;
                    startDate: string;
                    endDate: string;
                    schemaId: string;
                }[] | null | undefined;
                animatedTile: string | null | undefined;
                bookmark: boolean | null | undefined;
                hideWhiteShadow: boolean | null | undefined;
                unlockTimerSeconds: number | null | undefined;
            };
            "override-freeContentAmount": boolean | null | undefined;
            "new-freeContentAmount": number | null | undefined;
            blockedByPaywall: boolean | null | undefined;
        }[];
    };
    "chosen-one-games": {
        filter: {
            id?: string | undefined;
            conditions?: {
                type?: "language" | "subscriptionKind" | "ios_version" | "android_version" | "memory_size" | "permissions" | "platform" | "client_version" | undefined;
                mod?: "==" | "<" | "<=" | ">" | ">=" | "!=" | "in" | undefined;
                value?: string | undefined;
            }[] | undefined;
        }[];
        tile: {
            title: {
                ru?: string | null | undefined;
                en?: string | null | undefined;
            } | null | undefined;
            filter: {
                id?: string | undefined;
                conditions?: {
                    type?: "language" | "subscriptionKind" | "ios_version" | "android_version" | "memory_size" | "permissions" | "platform" | "client_version" | undefined;
                    mod?: "==" | "<" | "<=" | ">" | ">=" | "!=" | "in" | undefined;
                    value?: string | undefined;
                }[] | undefined;
            }[];
            "tech-name": string | null | undefined;
            subtitle: {
                ru?: string | null | undefined;
                en?: string | null | undefined;
            } | null | undefined;
            topTitle: {
                ru?: string | null | undefined;
                en?: string | null | undefined;
            } | null | undefined;
            target: {
                configUrl: string | null | undefined;
                type: "bg";
                gameId: string;
                restrictInOffline: boolean | null | undefined;
                params: {
                    name: string;
                    value: {};
                }[];
            } | {
                type: "mg";
                gameId: string;
                restrictInOffline: boolean | null | undefined;
            } | ({
                type: "partner";
                name: string;
            } & {
                restrictInOffline?: boolean | null | undefined;
            }) | {
                type: "island";
                restrictInOffline: boolean | null | undefined;
            } | {
                configUrl: string | null | undefined;
                type: "wg";
                gameId: string;
                restrictInOffline: boolean | null | undefined;
            } | ({
                type: "locked";
                gameId: string;
            } & {
                restrictInOffline?: boolean | null | undefined;
                params?: {
                    name: string;
                    value: {};
                }[] | null | undefined;
            });
            img700x500: string | null | undefined;
            previewAnimation: string | null | undefined;
            tags: {
                name: {
                    ru?: string | null | undefined;
                    en?: string | null | undefined;
                };
                color: string;
            }[] | null | undefined;
            freeContentAmount: number | null | undefined;
            blockedByPaywall: boolean | null | undefined;
            availableFrom: string | null | undefined;
            update: {
                id: string;
                startDate: string;
                endDate: string;
                schemaId: string;
            }[] | null | undefined;
            animatedTile: string | null | undefined;
            bookmark: boolean | null | undefined;
            hideWhiteShadow: boolean | null | undefined;
            unlockTimerSeconds: number | null | undefined;
        };
        "override-freeContentAmount": boolean | null | undefined;
        "new-freeContentAmount": number | null | undefined;
        blockedByPaywall: boolean | null | undefined;
        event: {
            img: string;
            name: {
                ru?: string | null | undefined;
                en?: string | null | undefined;
            };
        };
        "start-date": string;
        "end-date": string;
    }[];
    "start-screen": {
        video: string;
        poster: string;
    };
} | undefined>;
export declare const findSection: (root: CatalogConfig, path: string[]) => {
    name: string;
    tile: {
        tiles: CatalogConfig["tiles"];
    };
} | null;
export declare const flatTiles: (root?: CatalogConfig) => CatalogTileWrapper[];
export declare const flatAndDeleteDuplicates: (root?: CatalogConfig) => CatalogTileWrapper[];
export declare const findSectionWithGame: (config: CatalogConfig, gameId: string) => string[];
/**
 * @param callback - возвращает {boolean} стоит ли отфильтровать элемент из массива по значению false
 */
export declare const filterSection: (data: CatalogTileOrSectionWrapper[], callback: (c: CatalogTileOrSectionWrapper) => boolean) => CatalogTileOrSectionWrapper[];
export declare function throttle<T extends (...args: any) => any>(func: T, limit: number): (...args: Parameters<T>) => ReturnType<T>;
export declare const pick: <Obj extends object, Keys extends keyof Obj>(obj: Obj, keys: Keys[]) => { [Key in Keys]: Obj[Key]; };
export declare const deriveFreeContentAmount: <T extends Pick<{
    repeat: number | null | undefined;
    filter: {
        id?: string | undefined;
        conditions?: {
            type?: "language" | "subscriptionKind" | "ios_version" | "android_version" | "memory_size" | "permissions" | "platform" | "client_version" | undefined;
            mod?: "==" | "<" | "<=" | ">" | ">=" | "!=" | "in" | undefined;
            value?: string | undefined;
        }[] | undefined;
    }[];
    tile: CatalogSection | {
        title: {
            ru?: string | null | undefined;
            en?: string | null | undefined;
        } | null | undefined;
        filter: {
            id?: string | undefined;
            conditions?: {
                type?: "language" | "subscriptionKind" | "ios_version" | "android_version" | "memory_size" | "permissions" | "platform" | "client_version" | undefined;
                mod?: "==" | "<" | "<=" | ">" | ">=" | "!=" | "in" | undefined;
                value?: string | undefined;
            }[] | undefined;
        }[];
        "tech-name": string | null | undefined;
        subtitle: {
            ru?: string | null | undefined;
            en?: string | null | undefined;
        } | null | undefined;
        topTitle: {
            ru?: string | null | undefined;
            en?: string | null | undefined;
        } | null | undefined;
        target: {
            configUrl: string | null | undefined;
            type: "bg";
            gameId: string;
            restrictInOffline: boolean | null | undefined;
            params: {
                name: string;
                value: {};
            }[];
        } | {
            type: "mg";
            gameId: string;
            restrictInOffline: boolean | null | undefined;
        } | ({
            type: "partner";
            name: string;
        } & {
            restrictInOffline?: boolean | null | undefined;
        }) | {
            type: "island";
            restrictInOffline: boolean | null | undefined;
        } | {
            configUrl: string | null | undefined;
            type: "wg";
            gameId: string;
            restrictInOffline: boolean | null | undefined;
        } | ({
            type: "locked";
            gameId: string;
        } & {
            restrictInOffline?: boolean | null | undefined;
            params?: {
                name: string;
                value: {};
            }[] | null | undefined;
        });
        img700x500: string | null | undefined;
        previewAnimation: string | null | undefined;
        tags: {
            name: {
                ru?: string | null | undefined;
                en?: string | null | undefined;
            };
            color: string;
        }[] | null | undefined;
        freeContentAmount: number | null | undefined;
        blockedByPaywall: boolean | null | undefined;
        availableFrom: string | null | undefined;
        update: {
            id: string;
            startDate: string;
            endDate: string;
            schemaId: string;
        }[] | null | undefined;
        animatedTile: string | null | undefined;
        bookmark: boolean | null | undefined;
        hideWhiteShadow: boolean | null | undefined;
        unlockTimerSeconds: number | null | undefined;
    };
    disabled: boolean | null | undefined;
    return: boolean | null | undefined;
    highlighted: boolean | null | undefined;
    tilesize: "small" | "large" | null | undefined;
    "override-freeContentAmount": boolean | null | undefined;
    "new-freeContentAmount": number | null | undefined;
} & {
    "animation-id"?: string | null | undefined;
    blockedByPaywall?: boolean | null | undefined;
}, "override-freeContentAmount" | "new-freeContentAmount"> & {
    tile: CatalogTile;
}>(section?: T | undefined) => number;
export declare const blockedByPaywall: (section?: Pick<CatalogTileOrSectionWrapper, "blockedByPaywall"> & {
    tile: CatalogTile;
}) => boolean;
export declare const trycatch: <T extends (args: any) => any, Args extends Parameters<T>, Result_1 extends ReturnType<T>>(f: (...args: Args) => Result_1, onError?: ((err: unknown) => void) | undefined) => (...args: Args) => Result_1 | undefined;
export declare const escapeRegExp: (string: string) => string;
/**
 * Функция позволяет отменить обработку промиса, если истекло время ожидания
 * @param p - промис
 * @param timeout - таймаут, по истечении которого промис отклоняется
 * @returns результат промиса p или Promise.reject с сообщением "timeout", если время ожидания истекло
 */
export declare const asyncWithTimeout: <T>(p: Promise<T>, timeout: number) => Promise<unknown>;
export declare const hasYandexSub: (subscriptionKind: YandexAuth["subscriptionKind"], isKidsAvailable: boolean) => boolean;
export declare const getGameConfigUrl: (target: TileTarget, remoteConfigUrl?: string) => string | null | undefined;
export declare const getGamePayload: (gamesDifficulties: Record<string, string>, extraGameParams: Record<string, string>, configUrl: string) => (target: TileTarget) => {
    gameId: string;
    configUrl: string | null | undefined;
    gameParams: {
        blockedByPaywall: boolean;
        freeContentAmount: number;
        difficulty: string;
        gamer: string;
        params: {
            name: string;
            value: {};
        }[];
    };
    m: string;
};
export declare const transformGameMapConfig: (transformer: ReturnType<typeof getGamePayload>) => (source: GameMapConfigSource) => GameMapConfigTransformed;
export declare const tryAwait: <T extends unknown>(p: Promise<T>, def: T) => Promise<T>;
export declare const getIntercomUserInfo: (model: Initialize) => IntercomUserInfo;
//# sourceMappingURL=utils.d.ts.map